'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var srcFoundations = require('@guardian/src-foundations');

// babel * typescript * rollup = ¯\_(ツ)_/¯

var minWidth = function minWidth(from) {
  return "@media (min-width: ".concat("".concat(from, "px"), ")");
};

var maxWidth = function maxWidth(until) {
  return "@media (max-width: ".concat("".concat(until - 1, "px"), ")");
};

var minWidthMaxWidth = function minWidthMaxWidth(from, until) {
  return "@media (min-width: ".concat("".concat(from, "px"), ") and (max-width: ", "".concat(until - 1, "px"), ")");
}; // e.g. from.*


var from = {
  mobileMedium: minWidth(srcFoundations.breakpoints.mobileMedium),
  mobileLandscape: minWidth(srcFoundations.breakpoints.mobileLandscape),
  phablet: minWidth(srcFoundations.breakpoints.phablet),
  tablet: minWidth(srcFoundations.breakpoints.tablet),
  desktop: minWidth(srcFoundations.breakpoints.desktop),
  leftCol: minWidth(srcFoundations.breakpoints.leftCol),
  wide: minWidth(srcFoundations.breakpoints.wide) // e.g. until.*

};
var until = {
  mobileMedium: maxWidth(srcFoundations.breakpoints.mobileMedium),
  mobileLandscape: maxWidth(srcFoundations.breakpoints.mobileLandscape),
  phablet: maxWidth(srcFoundations.breakpoints.phablet),
  tablet: maxWidth(srcFoundations.breakpoints.tablet),
  desktop: maxWidth(srcFoundations.breakpoints.desktop),
  leftCol: maxWidth(srcFoundations.breakpoints.leftCol),
  wide: maxWidth(srcFoundations.breakpoints.wide) // e.g. between.*.and.*

};
var between = {
  mobileMedium: {
    and: {
      mobileLandscape: minWidthMaxWidth(srcFoundations.breakpoints.mobileMedium, srcFoundations.breakpoints.mobileLandscape),
      phablet: minWidthMaxWidth(srcFoundations.breakpoints.mobileMedium, srcFoundations.breakpoints.phablet),
      tablet: minWidthMaxWidth(srcFoundations.breakpoints.mobileMedium, srcFoundations.breakpoints.tablet),
      desktop: minWidthMaxWidth(srcFoundations.breakpoints.mobileMedium, srcFoundations.breakpoints.desktop),
      leftCol: minWidthMaxWidth(srcFoundations.breakpoints.mobileMedium, srcFoundations.breakpoints.leftCol),
      wide: minWidthMaxWidth(srcFoundations.breakpoints.mobileMedium, srcFoundations.breakpoints.wide)
    }
  },
  mobileLandscape: {
    and: {
      phablet: minWidthMaxWidth(srcFoundations.breakpoints.mobileLandscape, srcFoundations.breakpoints.phablet),
      tablet: minWidthMaxWidth(srcFoundations.breakpoints.mobileLandscape, srcFoundations.breakpoints.tablet),
      desktop: minWidthMaxWidth(srcFoundations.breakpoints.mobileLandscape, srcFoundations.breakpoints.desktop),
      leftCol: minWidthMaxWidth(srcFoundations.breakpoints.mobileLandscape, srcFoundations.breakpoints.leftCol),
      wide: minWidthMaxWidth(srcFoundations.breakpoints.mobileLandscape, srcFoundations.breakpoints.wide)
    }
  },
  phablet: {
    and: {
      tablet: minWidthMaxWidth(srcFoundations.breakpoints.phablet, srcFoundations.breakpoints.tablet),
      desktop: minWidthMaxWidth(srcFoundations.breakpoints.phablet, srcFoundations.breakpoints.desktop),
      leftCol: minWidthMaxWidth(srcFoundations.breakpoints.phablet, srcFoundations.breakpoints.leftCol),
      wide: minWidthMaxWidth(srcFoundations.breakpoints.phablet, srcFoundations.breakpoints.wide)
    }
  },
  tablet: {
    and: {
      desktop: minWidthMaxWidth(srcFoundations.breakpoints.tablet, srcFoundations.breakpoints.desktop),
      leftCol: minWidthMaxWidth(srcFoundations.breakpoints.tablet, srcFoundations.breakpoints.leftCol),
      wide: minWidthMaxWidth(srcFoundations.breakpoints.tablet, srcFoundations.breakpoints.wide)
    }
  },
  desktop: {
    and: {
      leftCol: minWidthMaxWidth(srcFoundations.breakpoints.desktop, srcFoundations.breakpoints.leftCol),
      wide: minWidthMaxWidth(srcFoundations.breakpoints.desktop, srcFoundations.breakpoints.wide)
    }
  },
  leftCol: {
    and: {
      wide: minWidthMaxWidth(srcFoundations.breakpoints.leftCol, srcFoundations.breakpoints.wide)
    }
  }
};

Object.defineProperty(exports, 'breakpoints', {
	enumerable: true,
	get: function () {
		return srcFoundations.breakpoints;
	}
});
exports.between = between;
exports.from = from;
exports.until = until;
